Package: VectraPolarisData
Title: Vectra Polaris and Vectra 3 multiplex single-cell imaging data
Version: 1.15.0
Date: 2022-03-31
Authors@R: c(
    person("Wrobel", "Julia", , "julia.wrobel@cuanschutz.edu", role = c("aut", "cre"),
    comment = c(ORCID = "0000-0001-6783-1421")),
    person("Tusharkanti", "Ghosh", role = "aut", email = "tusharkanti.ghosh@cuanschutz.edu"))
Description: Provides two multiplex imaging datasets collected on Vectra instruments at the University of Colorado Anschutz Medical Campus.
    Data are provided as a Spatial Experiment objects. 
    Data is provided in tabular form and has been segmented and phenotyped using Inform software.
    Raw .tiff files are not included.
URL: https://github.com/julia-wrobel/VectraPolarisData
BugReports: https://support.bioconductor.org/t/VectraPolarisData
biocViews: ExperimentHub, ExperimentData, SpatialData, SingleCellData,
        Homo_sapiens_Data, ReproducibleResearch
Depends: ExperimentHub, SpatialExperiment, utils
RoxygenNote: 7.1.2
Suggests: BiocStyle, knitr, rmarkdown, dplyr
VignetteBuilder: knitr
Encoding: UTF-8
License: Artistic-2.0
git_url: https://git.bioconductor.org/packages/VectraPolarisData
git_branch: devel
git_last_commit: 5ad67c7
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 16:49:59 UTC; biocbuild
Author: Wrobel Julia [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6783-1421>),
  Tusharkanti Ghosh [aut]
Maintainer: Wrobel Julia <julia.wrobel@cuanschutz.edu>
